@@ -25,7 +25,7 @@ import inspect
 import os
 import warnings
 from enum import Enum, IntEnum, unique
-from typing import TYPE_CHECKING, Any, Collection, Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Any, Collection, Dict, List, Optional, TypeVar, Union
 
 import attr
 
@@ -46,6 +46,8 @@ __all__ = ["settings"]
 
 all_settings: Dict[str, "Setting"] = {}
 
+T = TypeVar("T")
+
 
 class settingsProperty:
     def __init__(self, name, show_default):
@@ -181,12 +183,18 @@ class settings(metaclass=settingsMeta):
                 else:
                     object.__setattr__(self, setting.name, setting.validator(value))
 
-    def __call__(self, test):
+    def __call__(self, test: T) -> T:
         """Make the settings object (self) an attribute of the test.
 
         The settings are later discovered by looking them up on the test itself.
         """
-        if not callable(test):
+        # Aliasing as Any avoids mypy errors (attr-defined) when accessing and
+        # setting custom attributes on the decorated function or class.
+        _test: Any = test
+
+        # Using the alias here avoids a mypy error (return-value) later when
+        # ``test`` is returned, because this check results in type refinement.
+        if not callable(_test):
             raise InvalidArgument(
                 "settings objects can be called as a decorator with @given, "
                 f"but decorated test={test!r} is not callable."
@@ -194,7 +202,7 @@ class settings(metaclass=settingsMeta):
         if inspect.isclass(test):
             from hypothesis.stateful import RuleBasedStateMachine
 
-            if issubclass(test, RuleBasedStateMachine):
+            if issubclass(_test, RuleBasedStateMachine):
                 attr_name = "_hypothesis_internal_settings_applied"
                 if getattr(test, attr_name, False):
                     raise InvalidArgument(
@@ -203,25 +211,25 @@ class settings(metaclass=settingsMeta):
                         "instead."
                     )
                 setattr(test, attr_name, True)
-                test.TestCase.settings = self
+                _test.TestCase.settings = self
                 return test
             else:
                 raise InvalidArgument(
                     "@settings(...) can only be used as a decorator on "
                     "functions, or on subclasses of RuleBasedStateMachine."
                 )
-        if hasattr(test, "_hypothesis_internal_settings_applied"):
+        if hasattr(_test, "_hypothesis_internal_settings_applied"):
             # Can't use _hypothesis_internal_use_settings as an indicator that
             # @settings was applied, because @given also assigns that attribute.
             descr = get_pretty_function_description(test)
             raise InvalidArgument(
                 f"{descr} has already been decorated with a settings object.\n"
-                f"    Previous:  {test._hypothesis_internal_use_settings!r}\n"
+                f"    Previous:  {_test._hypothesis_internal_use_settings!r}\n"
                 f"    This:  {self!r}"
             )
 
-        test._hypothesis_internal_use_settings = self
-        test._hypothesis_internal_settings_applied = True
+        _test._hypothesis_internal_use_settings = self
+        _test._hypothesis_internal_settings_applied = True
         return test
 
     @classmethod
@@ -432,6 +440,7 @@ class Phase(IntEnum):
     generate = 2
     target = 3
     shrink = 4
+    explain = 5
 
     def __repr__(self):
         return f"Phase.{self.name}"
@@ -523,7 +532,9 @@ def _validate_phases(phases):
 
 settings._define_setting(
     "phases",
-    default=tuple(Phase),
+    # We leave the `explain` phase disabled by default, for speed and brevity
+    # TODO: consider default-enabling this in CI?
+    default=_validate_phases(set(Phase) - {Phase.explain}),
     description=(
         "Control which phases should be run. "
         "See :ref:`the full documentation for more details <phases>`"
