@@ -27,6 +27,7 @@ import traceback
 import types
 import warnings
 import zlib
+from collections import defaultdict
 from inspect import getfullargspec
 from io import StringIO
 from random import Random
@@ -61,12 +62,13 @@ from hypothesis.errors import (
 )
 from hypothesis.executors import new_style_executor
 from hypothesis.internal.compat import (
+    PYPY,
     bad_django_TestCase,
     get_type_hints,
     int_from_bytes,
     qualname,
 )
-from hypothesis.internal.conjecture.data import ConjectureData
+from hypothesis.internal.conjecture.data import ConjectureData, Status
 from hypothesis.internal.conjecture.engine import ConjectureRunner
 from hypothesis.internal.conjecture.shrinker import sort_key
 from hypothesis.internal.entropy import deterministic_PRNG
@@ -86,6 +88,7 @@ from hypothesis.internal.reflection import (
     is_mock,
     proxies,
 )
+from hypothesis.internal.scrutineer import Tracer, explanatory_lines
 from hypothesis.reporting import (
     current_verbosity,
     report,
@@ -523,6 +526,8 @@ class StateForActualGivenExecution:
         self.files_to_propagate = set()
         self.failed_normally = False
 
+        self.explain_traces = defaultdict(set)
+
     def execute_once(
         self, data, print_example=False, is_final=False, expected_failure=None
     ):
@@ -591,31 +596,12 @@ class StateForActualGivenExecution:
                                     for v in args:
                                         printer.pretty(v)
                                         # We add a comma unconditionally because
-                                        # generated arguments will always be
-                                        # kwargs, so there will always be more
-                                        # to come.
+                                        # generated arguments will always be kwargs,
+                                        # so there will always be more to come.
                                         printer.text(",")
                                         printer.breakable()
 
-                                    # We need to make sure to print these in the
-                                    # argument order for Python 2 and older versions
-                                    # of Python 3.5. In modern versions this isn't
-                                    # an issue because kwargs is ordered.
-                                    arg_order = {
-                                        v: i
-                                        for i, v in enumerate(
-                                            getfullargspec(self.test).args
-                                        )
-                                    }
-                                    for i, (k, v) in enumerate(
-                                        sorted(
-                                            kwargs.items(),
-                                            key=lambda t: (
-                                                arg_order.get(t[0], float("inf")),
-                                                t[0],
-                                            ),
-                                        )
-                                    ):
+                                    for i, (k, v) in enumerate(kwargs.items()):
                                         printer.text(k)
                                         printer.text("=")
                                         printer.pretty(v)
@@ -675,7 +661,26 @@ class StateForActualGivenExecution:
         ``StopTest`` must be a fatal error, and should stop the entire engine.
         """
         try:
-            result = self.execute_once(data)
+            trace = frozenset()
+            if (
+                self.failed_normally
+                and Phase.explain in self.settings.phases
+                and sys.gettrace() is None
+                and not PYPY
+            ):  # pragma: no cover
+                # This is in fact covered by our *non-coverage* tests, but due to the
+                # settrace() contention *not* by our coverage tests.  Ah well.
+                tracer = Tracer()
+                try:
+                    sys.settrace(tracer.trace)
+                    result = self.execute_once(data)
+                    if data.status == Status.VALID:
+                        self.explain_traces[None].add(frozenset(tracer.branches))
+                finally:
+                    sys.settrace(None)
+                    trace = frozenset(tracer.branches)
+            else:
+                result = self.execute_once(data)
             if result is not None:
                 fail_health_check(
                     self.settings,
@@ -721,7 +726,13 @@ class StateForActualGivenExecution:
                 info.__expected_exception = e
                 verbose_report(info.__expected_traceback)
 
-                data.mark_interesting(get_interesting_origin(e))
+                self.failed_normally = True
+
+                interesting_origin = get_interesting_origin(e)
+                if trace:  # pragma: no cover
+                    # Trace collection is explicitly disabled under coverage.
+                    self.explain_traces[interesting_origin].add(trace)
+                data.mark_interesting(interesting_origin)
 
     def run_engine(self):
         """Run the test function many times, on database input and generated
@@ -772,8 +783,6 @@ class StateForActualGivenExecution:
         # The engine found one or more failures, so we need to reproduce and
         # report them.
 
-        self.failed_normally = True
-
         flaky = 0
 
         if runner.best_observed_targets:
@@ -781,6 +790,7 @@ class StateForActualGivenExecution:
                 report(line)
             report("")
 
+        explanations = explanatory_lines(self.explain_traces, self.settings)
         for falsifying_example in self.falsifying_examples:
             info = falsifying_example.extra_information
 
@@ -804,6 +814,10 @@ class StateForActualGivenExecution:
                     "assumptions on the first run now fails it."
                 )
             except BaseException as e:
+                # If we have anything for explain-mode, this is the time to report.
+                for line in explanations[falsifying_example.interesting_origin]:
+                    report(line)
+
                 if len(self.falsifying_examples) <= 1:
                     # There is only one failure, so we can report it by raising
                     # it directly.
@@ -957,10 +971,8 @@ def given(
         # positional arguments into keyword arguments for simplicity.
         if given_arguments:
             assert not given_kwargs
-            for name, strategy in zip(
-                reversed(original_argspec.args), reversed(given_arguments)
-            ):
-                given_kwargs[name] = strategy
+            nargs = len(given_arguments)
+            given_kwargs.update(zip(original_argspec.args[-nargs:], given_arguments))
         # These have been converted, so delete them to prevent accidental use.
         del given_arguments
 
@@ -1278,8 +1290,11 @@ def find(
     if random is not None:
         test = seed(random.getrandbits(64))(test)
 
-    test._hypothesis_internal_is_find = True
-    test._hypothesis_internal_database_key = database_key
+    # Aliasing as Any avoids mypy errors (attr-defined) when accessing and
+    # setting custom attributes on the decorated function or class.
+    _test: Any = test
+    _test._hypothesis_internal_is_find = True
+    _test._hypothesis_internal_database_key = database_key
 
     try:
         test()
