@@ -588,6 +588,11 @@ ROUNDTRIP_PAIRS = (
     (r"(.+)2(.+?)(_.+)?", "{1}2{0}{2}"),
     # Common in e.g. the colorsys module
     (r"(.+)_to_(.+)", "{1}_to_{0}"),
+    # Sockets patterns
+    (r"(inet|if)_(.+)to(.+)", "{0}_{2}to{1}"),
+    (r"(\w)to(\w)(.+)", "{1}to{0}{2}"),
+    (r"send(.+)", "recv{}"),
+    (r"send(.+)", "receive{}"),
 )
 
 
@@ -648,12 +653,21 @@ def magic(
 
     imports = set()
     parts = []
+
+    def make_(how, *args, **kwargs):
+        imp, body = how(*args, **kwargs, except_=except_, style=style)
+        imports.update(imp)
+        parts.append(body)
+
     by_name = {}
     for f in functions:
         try:
+            _get_params(f)
             by_name[_get_qualname(f, include_module=True)] = f
         except Exception:
-            pass  # e.g. Pandas 'CallableDynamicDoc' object has no attribute '__name__'
+            # usually inspect.signature on C code such as socket.inet_aton, sometimes
+            # e.g. Pandas 'CallableDynamicDoc' object has no attribute '__name__'
+            pass
     if not by_name:
         return (
             f"# Found no testable functions in\n"
@@ -668,14 +682,20 @@ def magic(
                 inverse_name = readname.format(*match.groups())
                 for other in sorted(
                     n for n in by_name if n.split(".")[-1] == inverse_name
-                )[:1]:
-                    imp, body = _make_roundtrip_body(
-                        (by_name.pop(name), by_name.pop(other)),
-                        except_=except_,
-                        style=style,
-                    )
-                    imports |= imp
-                    parts.append(body)
+                ):
+                    make_(_make_roundtrip_body, (by_name.pop(name), by_name.pop(other)))
+                    break
+                else:
+                    try:
+                        other_func = getattr(
+                            sys.modules[_get_module(by_name[name])],
+                            inverse_name,
+                        )
+                        _get_params(other_func)  # we want to skip if this fails
+                    except Exception:
+                        pass
+                    else:
+                        make_(_make_roundtrip_body, (by_name.pop(name), other_func))
 
     # Look for equivalent functions: same name, all required arguments of any can
     # be found in all signatures, and if all have return-type annotations they match.
@@ -687,9 +707,7 @@ def magic(
             sentinel = object()
             returns = {get_type_hints(f).get("return", sentinel) for f in group}
             if len(returns - {sentinel}) <= 1:
-                imp, body = _make_equiv_body(group, except_=except_, style=style)
-                imports |= imp
-                parts.append(body)
+                make_(_make_equiv_body, group)
                 for f in group:
                     by_name.pop(_get_qualname(f, include_module=True))
 
@@ -703,29 +721,21 @@ def magic(
             a, b = hints.values()
             arg1, arg2 = params
             if a == b and len(arg1) == len(arg2) <= 3:
-                imp, body = _make_binop_body(func, except_=except_, style=style)
-                imports |= imp
-                parts.append(body)
+                make_(_make_binop_body, func)
                 del by_name[name]
 
     # Look for Numpy ufuncs or gufuncs, and write array-oriented tests for them.
     if "numpy" in sys.modules:
         for name, func in sorted(by_name.items()):
             if _is_probably_ufunc(func):
-                imp, body = _make_ufunc_body(func, except_=except_, style=style)
-                imports |= imp
-                parts.append(body)
+                make_(_make_ufunc_body, func)
                 del by_name[name]
 
     # For all remaining callables, just write a fuzz-test.  In principle we could
     # guess at equivalence or idempotence; but it doesn't seem accurate enough to
     # be worth the trouble when it's so easy for the user to specify themselves.
     for _, f in sorted(by_name.items()):
-        imp, body = _make_test_body(
-            f, test_body=_write_call(f), except_=except_, ghost="fuzz", style=style
-        )
-        imports |= imp
-        parts.append(body)
+        make_(_make_test_body, f, test_body=_write_call(f), ghost="fuzz")
     return _make_test(imports, "\n".join(parts))
 
 
@@ -1130,6 +1140,7 @@ def _make_ufunc_body(func, *, except_, style):
         type_assert=_assert_eq(style, "result.dtype.char", "expected_dtype"),
     )
 
+    qname = _get_qualname(func, include_module=True)
     return _make_test_body(
         func,
         test_body=dedent(body).strip(),
@@ -1139,7 +1150,6 @@ def _make_ufunc_body(func, *, except_, style):
         given_strategies={
             "data": st.data(),
             "shapes": shapes,
-            "types": f"sampled_from({_get_qualname(func, include_module=True)}.types)"
-            ".filter(lambda sig: 'O' not in sig)",
+            "types": f"sampled_from([sig for sig in {qname}.types if 'O' not in sig])",
         },
     )
