@@ -1,7 +1,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2020 David R. MacIver
+# Most of this work is copyright (C) 2013-2021 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -32,17 +32,17 @@ def describe_targets(best_targets):
     """Return a list of lines describing the results of `target`, if any."""
     # These lines are included in the general statistics description below,
     # but also printed immediately below failing examples to alleviate the
-    # "threshold problem" where shrinking can make severe bug look trival.
+    # "threshold problem" where shrinking can make severe bug look trivial.
     # See https://github.com/HypothesisWorks/hypothesis/issues/2180
     if not best_targets:
         return []
     elif len(best_targets) == 1:
         label, score = next(iter(best_targets.items()))
-        return ["Highest target score: {:g}  (label={!r})".format(score, label)]
+        return [f"Highest target score: {score:g}  (label={label!r})"]
     else:
         lines = ["Highest target scores:"]
         for label, score in sorted(best_targets.items(), key=lambda x: x[::-1]):
-            lines.append("{:>16g}  (label={!r})".format(score, label))
+            lines.append(f"{score:>16g}  (label={label!r})")
         return lines
 
 
@@ -75,9 +75,9 @@ def describe_statistics(stats_dict):
         if upper == 0:
             ms = "< 1ms"
         elif lower == upper:
-            ms = "~ %dms" % (lower,)
+            ms = f"~ {lower}ms"
         else:
-            ms = "%d-%d ms" % (lower, upper)
+            ms = f"{lower}-{upper} ms"
         drawtime_percent = 100 * statistics.mean(
             t["drawtime"] / t["runtime"] if t["runtime"] > 0 else 0 for t in cases
         )
