@@ -17,7 +17,17 @@ import sys
 import warnings
 from collections import defaultdict
 from random import choice as random_choice
-from typing import Any, Callable, Generic, List, Sequence, TypeVar, Union, overload
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Generic,
+    List,
+    Sequence,
+    TypeVar,
+    Union,
+    overload,
+)
 
 from hypothesis._settings import HealthCheck, Phase, Verbosity, settings
 from hypothesis.control import _current_build_context, assume
@@ -310,7 +320,7 @@ class SearchStrategy(Generic[Ex]):
         def example_generating_inner_function(ex):
             examples.append(ex)
 
-        examples = []  # type: List[Ex]
+        examples: List[Ex] = []
         example_generating_inner_function()
         return random_choice(examples)
 
@@ -381,7 +391,7 @@ class SearchStrategy(Generic[Ex]):
             self.validate_called = False
             raise
 
-    LABELS = {}  # type: dict
+    LABELS: Dict[type, int] = {}
 
     @property
     def class_label(self):
@@ -642,6 +652,12 @@ class OneOfStrategy(SearchStrategy):
         else:
             return [self]
 
+    def filter(self, condition):
+        return FilteredStrategy(
+            OneOfStrategy([s.filter(condition) for s in self.original_strategies]),
+            conditions=(),
+        )
+
 
 @overload
 def one_of(args: Sequence[SearchStrategy[Any]]) -> SearchStrategy[Any]:
@@ -770,7 +786,7 @@ class MappedSearchStrategy(SearchStrategy):
     def pack(self, x):
         """Take a value produced by the underlying mapped_strategy and turn it
         into a value suitable for outputting from this strategy."""
-        raise NotImplementedError("%s.pack()" % (self.__class__.__name__))
+        raise NotImplementedError(f"{self.__class__.__name__}.pack()")
 
     def do_draw(self, data: ConjectureData) -> Ex:
         for _ in range(3):
